\name{est.variogram}
\title{Variogram Estimator}
\usage{est.variogram(point.obj, pair.obj, a1, a2) }
\alias{est.variogram}
\arguments{
\item{point.obj}{a point object generated by \code{point()}}
\item{pair.obj}{a pair object generated by \code{pair()}}
\item{a1}{a variable to calculate semivariogram for}
\item{a2}{an optional variable name, if entered cross variograms will be created between \code{a1} and \code{a2}}
}
\value{A variogram object:
\item{lags}{vector of lag identifiers}
\item{bins}{vector of midpoints of each lag}
\item{classic}{vector of classic variogram estimates for each lag}
\item{robust}{vector of robust variogram estimates for each lag}
\item{med}{vector of median variogram estimates for each lag}
\item{n}{vector of the number of pairs in each lag}
}
\description{Calculate empirical variogram estimates. 

An object of class \code{variogram} contains empirical variogram estimates generated from a point object and a pair object. A
variogram object is stored as a data frame containing six columns: \code{lags}, \code{bins}, \code{classic}, \code{robust}, \code{med}, and \code{n}. The length of each
vector is equal to the number of lags in the pair object used to create the variogram object, say l. The \code{lags} vector contains the
lag numbers for each lag, beginning with one (1) and going to the number of lags (l). The \code{bins} vector contains the spatial midpoint
of each lag. The \code{classic}, \code{robust}, and \code{med} vectors contain the classical,
\deqn{\gamma_{c}(h)=\frac{1}{n}\sum_{(i,j) \in
    N(h)}(z(x_{i})-z(x_{j}))^{2}}{classic(h)= 1/n sum_(i,j)_in_N(h) (z(x_i)-z(x_j))^2 }

robust,
\deqn{\gamma_{m}(h)=\frac{(\frac{1}{n}\sum_{(i,j) \in N(h)}
    (\sqrt{|z(x_{i})-z(x_{j})|}))^{4}}{0.457 +
    \frac{0.494}{n}}}{robust(h)=(1/n sum_(i,j)_in_N(h)
  sqrt(|z(x_i)-z(x_j)|) )^4/(0.457 + 0.494/n)}

and median
 \deqn{\gamma_{m}(h)=\frac{(\mbox{median}_{(i,j) \in N(h)}
     (\sqrt{|z(x_{i})-z(x_{j})|}))^{4}}{0.457 + \frac{0.494}{|N(h)|}}}{med(h)=(med_(i,j)_in_N(h)
  sqrt(|z(x_i)-z(x_j)|) )^4/(0.457 + 0.494/n)}
 
  variogram estimates for each lag, respectively (see Cressie, 1993, p. 75).
The \code{n} vector contains the number \eqn{|N(h)|} of pairs of points in each lag \eqn{N(h)}. }
\seealso{\code{\link{point}}, \code{\link{pair}}}
\examples{
\testonly{
# prepare variables from other example pages if they are not already there:
if(length(ls(pat="maas.pair"))==0){example(pair)}
}
maas.v<-est.variogram(maas.point,maas.pair,'zinc') 
}
\references{
http://www.gis.iastate.edu/SGeoStat/homepage.html
}
\keyword{spatial}

\eof
\name{fit.trend}
\alias{fit.trend}
\title{ Fit polynomial trend functions }
\description{
  Fits a polynomial trend function to a \code{\link{point}} object.
  Similar to functions in B. Ripleys spatial library.
}
\usage{
fit.trend(point.obj, at, np=2, plot.it=TRUE)
}
\arguments{
  \item{point.obj}{ \code{\link{point}} object }
  \item{at}{ name of dependent variable in \code{point.obj} }
  \item{np}{ degree of polynom to be fitted }
  \item{plot.it}{ switches generation of a contour plot }
}
\details{
}
\value{
  \item{beta}{estimated parameters}
  ...
}
\references{ 
http://www.gis.iastate.edu/SGeoStat/homepage.html
}

\examples{
}
\keyword{spatial}%-- one or more ...
\keyword{spatial}

\eof
\name{fit.variogram}
\title{Variogram Model Fit}
\usage{
fit.variogram(model="exponential", v.object, nugget, sill,
              range, slope, ...)
fit.exponential(v.object, c0, ce, ae, type='c', 
                iterations=10, tolerance=1e-06, echo=FALSE, plot.it=FALSE, weighted=TRUE)
fit.gaussian(v.object, c0, cg, ag, type='c', 
             iterations=10, tolerance=1e-06, echo=FALSE,  plot.it=FALSE, weighted=TRUE)
fit.spherical(v.object, c0, cs, as, type='c', iterations=10,
             tolerance=1e-06, echo=FALSE,  plot.it=FALSE, weighted=TRUE,
             delta=0.1, verbose=TRUE)
fit.wave(v.object, c0, cw, aw, type='c', 
         iterations=10, tolerance=1e-06, echo=FALSE,  plot.it=FALSE, weighted=TRUE)
fit.linear(v.object, type='c', plot.it=FALSE,iterations=1, c0=0, cl=1)}
\alias{fit.variogram}
\alias{fit.exponential}
\alias{fit.wave}
\alias{fit.gaussian}
\alias{fit.spherical}
\alias{fit.linear}
\arguments{
\item{model}{only available for \code{fit.variogram}, switches what kind
  of model should be fitted (\code{"exponential", "wave", "gaussian",
  "spherical", "linear"}).}
\item{v.object}{a variogram object generated by \code{est.variogram()}}
\item{nugget, sill, range, slope}{only available for \code{fit.variogram},
  initial estimates for specified variogram model (\code{slope} only for
  \code{fit.linear})}
\item{c0}{initial estimate for nugget effect, valid for all variogram
  types, partial sill (\code{cX}) and (asymptotical) range (\code{aX})
  as follows:}
\item{ce, ae}{initial estimates for the exponential variogram model}
\item{cg, ag}{initial estimates for the gaussian variogram model}
\item{cs, as}{initial estimates for the sperical variogram model}
\item{cw, aw}{initial estimates for the periodical variogram model}
\item{cl}{initial estimates for the linear variogram model (slope)}
\item{type}{one of \code{'c'} (classic), \code{'r'} (robust), \code{'m'} (median). Indicates to which type of empirical variogram estimate the model is
to be fit.}
\item{iterations}{the number of iterations of the fitting procedure to execute.}
\item{tolerance}{the tolerance used to determine if model convergence has been achieved.}
\item{delta}{initial stepsize (relative) for pseudo Newton approximation, applies only to \code{fit.spherical}}
\item{echo}{if TRUE, be verbose.}
\item{verbose}{if TRUE, be verbose (show iteration for spherical model fit).}
\item{plot.it}{if TRUE, the variogram estimate will be plotted each iteration.}
\item{weighted}{if TRUE, the fit will be done using weighted least squares,
  where the weightes are given in Cressie (1991, p. 99)}
\item{...}{only \code{fit.variogram}: additional parameters to hand
  through to specific model fit functions}
}
\value{A variogram.model object:
\item{parameters}{vector of fitted model parameters}
\item{model}{function implementing a valid variogram model}
}
\description{Fit variogram models (exponential, spherical, gaussian, linear) to empirical variogram estimates. 

  
  
An object of class variogram.model represents a fitted variogram model generated by fitting a function to a variogram object. A
variogram.model object is composed of a list consisting of a vector of parameters, \code{parameters}, and a semi-variogram model
function, \code{model}.
}
\note{\code{fit.exponential}, \code{fit.gaussian} and \code{fit.wave}
  use an iterative, Gauss-Newton fitting algorithm to fit to an
  exponential or gaussian variogram model to empirical variogram estimates.
\code{fit.spherical} uses the same algorithm but with differential
  quotients in place of first derivatives. When \code{weighted} is
  \code{TRUE}, the regression is weighted by \eqn{n(h)/gamma(h)^2} where
  the numerator is the number of pairs of points in a given lag.

  Setting \code{iterations} to 0 means no fit procedure is applied. Thus
  parameter values from external sources can be plugged into a variogram
  model object.
  }
\seealso{\code{\link{est.variogram}}}
\examples{
\testonly{
# prepare variables from other example pages if they are not already there:
if(length(ls(pat="maas.v"))==0){example(est.variogram)}
}
#
# automatic fit:
#
maas.vmod<-fit.gaussian(maas.v,c0=60000,cg=110000,ag=800,plot.it=TRUE,
iterations=30)
#
# iterations=0, means no fit, intended for "subjective" fit
#
maas.vmod.fixed<-fit.variogram("gaussian",maas.v,nugget=60000,sill=110000,range=800,plot.it=TRUE,iterations=0)
}
\references{
http://www.gis.iastate.edu/SGeoStat/homepage.html
}
\keyword{spatial}

\eof
\name{identify.point}
\title{Identify points on a Point Object}
\usage{identify.point(x, v, ...) }
\alias{identify.point}
\arguments{
  \item{x}{a point object generated by \code{point()}}
  \item{v}{use values of variable \code{"v"} as labels}
  \item{...}{additional arguments to \code{idententify}}
}
\value{An integer vector containing the indexes of
  the identified points.}
\description{
  Plot variable values next to locations after the \code{plot.point()} function. }
\seealso{\code{\link{plot.point}}}
\examples{
\testonly{
# prepare variables from other example pages if they are not already there:
if(length(ls(pat="maas.point"))==0){example(point)}
}
plot(maas.point)
# use indices as labels:
identify(maas.point)
# use values as labels:
identify(maas.point,v="zinc")
}
\references{
http://www.gis.iastate.edu/SGeoStat/homepage.html
}
\keyword{spatial}

\eof
\name{in.chull}
\alias{in.chull}
\title{ Convex hull test }
\description{
  Checks if points are in the interior of a convex hull.
}
\usage{
in.chull(x0, y0, x, y)
}
\arguments{
  \item{x0}{ coordinates of points to check }
  \item{y0}{ see \code{x0} }
  \item{x}{ coordinates defining the convex hull }
  \item{y}{  see \code{x}  }
}
\details{
  Uses a simple points-in-polygon check combined with the \code{\link[base]{chull}}
  function.
}
\value{
  \item{comp1 }{Description of `comp1'}
  \item{comp2 }{Description of `comp2'}
}
\references{ Follows an idea from algorithm 112 from CACM
     (available at http://www.netlib.org/tomspdf/112.pdf) }
\author{ Albrecht Gebhardt <agebhard@uni-klu.ac.at> }

\seealso{ \code{\link[tripack]{in.convex.hull}}, \code{\link[base]{chull}} }

\examples{
in.chull(c(0,1),c(0,1),c(0,1,0,-1),c(-1,0,1,0))
# should give: TRUE FALSE
}
\keyword{spatial}%-- one or more ...

\eof
\name{in.polygon}
\alias{in.polygon}
\title{ In-Polygon test }
\description{
  Checks if points are in the interior of a polygon.
}
\usage{
in.polygon(x0, y0, x, y)
}
\arguments{
  \item{x0}{ coordinates of points to check }
  \item{y0}{ see \code{x0} }
  \item{x}{ coordinates defining the polygon }
  \item{y}{  see \code{x}  }
}
\details{
  Uses a simple points-in-polygon check combined with the \code{\link[base]{polygon}}
  function.

  Polygon is closed automatically.
}
\value{
  \item{comp1 }{Description of `comp1'}
  \item{comp2 }{Description of `comp2'}
}
\references{ Follows an idea from algorithm 112 from CACM
     (available at http://www.netlib.org/tomspdf/112.pdf) }
\author{ Albrecht Gebhardt <agebhard@uni-klu.ac.at> }

\seealso{ \code{\link[tripack]{in.convex.hull}}, \code{\link[base]{polygon}},  \code{\link{in.chull}} }

\examples{
in.polygon(c(0,1),c(0,1),c(0,1,0,-1),c(-1,0,1,0))
# should give: TRUE FALSE
}
\keyword{spatial}%-- one or more ...

\eof
\name{krige}
\title{Kriging}
\usage{krige(s, point.obj, at, var.mod.obj, maxdist=NULL, extrap=FALSE, border) }
\alias{krige}
\arguments{
\item{s}{a point object, generated by \code{point()}, at which prediction is carried out}
\item{point.obj}{a point object, generated by \code{point()}, containing the sample points and data}
\item{at}{the variable, contained in \code{point.obj}, for which
  prediction will be carried out}
\item{var.mod.obj}{variogram object}
\item{maxdist}{an optional maximum distance. If entered, then only sample points (i.e, in point.obj) within maxdist of each
prediction point will be used to do the prediction at that point. If not entered, then all n sample points will be used to make
the prediction at each point.}
\item{extrap}{logical, indicates if prediction outside the convex hull of data points should be done, default \code{FALSE}}
\item{border}{optional polygon (list with two components \code{x} and \code{y} of
   same length) representing a (possibly non convex) region of interest to 
   be used instead of the convex hull. Needs \code{extrap=TRUE}.}
}
\value{A point object which is a copy of the \code{s} object with two new variables, \code{zhat} and \code{sigma2hat}, which are,
repspectively, the predicted value and the kriging variance. }
\description{Carry out spatial prediction (or kriging). }
\seealso{\code{\link{est.variogram}},\code{\link{fit.variogram}}}
\examples{
\testonly{
# prepare variables from other example pages if they are not already there:
if(length(ls(pat="maas.vmod"))==0){example(fit.variogram)}
}
# a single point:
prdpnt <- point(data.frame(list(x=180000,y=331000)))
prdpnt <- krige(prdpnt, maas.point, 'zinc', maas.vmod)
prdpnt

# kriging on a grid (slow!)
grid <- list(x=seq(min(maas$x),max(maas$x),by=100),
             y=seq(min(maas$y),max(maas$y),by=100))
grid$xr <- range(grid$x)
grid$xs <- grid$xr[2] - grid$xr[1]
grid$yr <- range(grid$y)
grid$ys <- grid$yr[2] - grid$yr[1]
grid$max <- max(grid$xs, grid$ys)
grid$xy <- data.frame(cbind(c(matrix(grid$x, length(grid$x), length(grid$y))),
             c(matrix(grid$y, length(grid$x), length(grid$y), byrow=TRUE))))
colnames(grid$xy) <- c("x", "y")
grid$point <- point(grid$xy)
data(maas.bank)
grid$krige <- krige(grid$point,maas.point,'zinc',maas.vmod,
                    maxdist=1000,extrap=FALSE,border=maas.bank)
op <- par(no.readonly = TRUE)
par(pty="s")
plot(grid$xy, type="n", xlim=c(grid$xr[1], grid$xr[1]+grid$max),
                    ylim=c(grid$yr[1], grid$yr[1]+grid$max))
image(grid$x,grid$y,
      matrix(grid$krige$zhat,length(grid$x),length(grid$y)),
      add=TRUE)
contour(grid$x,grid$y,
        matrix(grid$krige$zhat,length(grid$x),length(grid$y)),
        add=TRUE)
data(maas.bank)
lines(maas.bank$x,maas.bank$y,col="blue")
par(op)
}
\references{
http://www.gis.iastate.edu/SGeoStat/homepage.html
}
\keyword{spatial}

\eof
\name{lagplot}
\title{Lag Scatter Plot}
\usage{lagplot(point.obj, pair.obj, a1, a2, lag=1, std=FALSE, query.a, xlim, ylim)}
\alias{lagplot}
\arguments{
\item{point.obj}{a point object generated by \code{point()}}
\item{pair.obj}{a pair object generated by \code{pair()}}
\item{a1}{a variable to plot}
\item{a2}{an optional variable name, if entered the plot will be created between \code{a1} and \code{a2}}
\item{lag}{the lag to plot} 
\item{std}{a logical variable indicating whether the data should be standardized to their means and standard deviations before
plotting}
\item{query.a}{an optional variable name, if entered, the value of the variable will be displayed on the graphics device for points
identified by the user.}
\item{xlim}{a vector of length 2 indicating the x limits of the graphics page}
\item{ylim}{a vector of length 2 indicating the y limits of the graphics page}
}
\value{NULL}
\description{Create a spatially lagged scatter plot, e.g. plot z(s) versus z(s+h), where h is a lag in a pair object. }
\note{When \code{query.a} is entered, the user will be prompted to identify points on the display device. Because each point in the
plot represents a pair of locations, the user must identify each point twice, once for the "from" point and once for the "to"
point. Querying is ended by pressing the middle mouse button on the mouse while the cursor is in the display window. }
\seealso{\code{\link{point}}, \code{\link{pair}}}
\examples{
\testonly{
# prepare variables from other example pages if they are not already there:
if(length(ls(pat="maas.pair"))==0){example(pair)}
}
opar <- par(ask = interactive() && .Device == "X11")
lagplot(maas.point,maas.pair,'zinc')
# with identifying pairs:
lagplot(maas.point,maas.pair,'zinc',lag=2,query.a='zinc')
par(opar)
}
\references{
http://www.gis.iastate.edu/SGeoStat/homepage.html
}
\keyword{spatial}

\eof
\name{maas}
\alias{maas}
\title{maas- zinc measurements}
\usage{maas}
\description{
Zinc measurements as groundwater quality variable.
}
\value{list with components \code{x},\code{y} and \code{zinc}.
}
\references{
  gstat
  E.J Pebesma (E.J.Pebesma@frw.uva.nl) 
  http://www.frw.uva.nl/~pebesma/gstat/
}
\seealso{\code{\link{maas.bank}}}
\keyword{datasets}

\eof
\name{maas.bank}
\alias{maas.bank}
\title{maas.bank - coordinates}
\usage{maas.bank}
\description{
Coordinates of maas bank. To be used together with \code{\link{maas}}.
}
\value{list with components \code{x} and\code{y}..
}
\seealso{\code{\link{maas}}}
\references{
  gstat
  E.J Pebesma (E.J.Pebesma@frw.uva.nl) 
  http://www.frw.uva.nl/~pebesma/gstat/
}
\keyword{datasets}

\eof
\name{pair}
\title{Pair Object}
\usage{pair(point.obj,num.lags=10,type='isotropic', theta=0, dtheta=5, maxdist) }
\alias{pair}
\arguments{
\item{point.obj}{a point object generated by \code{point()}} 
\item{num.lags}{the number of lags into which to divide the pairs of points in the pair object. The lags are all of equal size.} 
\item{type}{either \code{
'isotropic'} or \code{'anisotropic'}. If \code{'isotropic'} then all \eqn{n \choose 2} possible pairs of points are represented in the pair
object. If \code{'anisotropic'}, then the arguments \code{theta} and \code{dtheta} are used to determine which pairs of points to include.}
\item{theta}{an angle, measured in degrees from the horizontal x axis, that determines pairs of points to be included in the \code{pair}
object (see Notes below).}
\item{dtheta}{a tolerance angle, around \code{theta}, measured in degrees that determines pairs of points to be included in the \code{pair}
object (see Notes below).}
\item{maxdist}{the distance beyond which not to consider pairs of points. A large number of spatial locations can cause the
\code{pair} function to consume a considerable amount of computation time. In most cases, spatial dependence can be
adaquately characterized without examining the entire spaital extent of the data set.}
}
\value{A \code{pair} object:
\item{from}{vector of indices into the point object for "from" point}
\item{to}{vector of indices into the point object for "to" point}
\item{lags}{vector of spatial lags of each pair}
\item{dist}{vector of distances between each pair}
\item{bins}{vector of spatial midpoints of each lag (used for plotting)}
 }
\description{Create a pair object from a point object.



A pair object contains information defining pairs of points contained in a point object. A pair object is a list containing five
vectors: \code{from}, \code{to}, \code{lags}, \code{dist}, and \code{bins}. The length of each of these vectors (except \code{bins}) is equal to the number of pairs of
points being represented, say k. The vectors \code{from} and \code{to} contain pointers into the vectors of a point object, pointing to each
member of the pair of points (e.g., from[k] points to si and to[k] points to sj). The vector \code{dist} contains the distance between the
pairs of points. The vector \code{lags} contains the lag number to which each pair of points has been assigned. The vector \code{bins} contains
the spatial midpoint between each lag and is used for plotting.  }
\note{When creating an anisotropic pair object, the assumption is that the direction, as well as the distance, between pairs of
points is important in describing the variation. Using the theta and dtheta arguments, pairs of points that meet direction
requirements can be selected. A pair of points will be included when the angle between the positive x axis and the vector
formed by the pair of points falls within the tolerance angle given by
\emph{(theta-dtheta,theta+dtheta)}}
\section{NOTE}{Name of this function changed from \code{pairs} to \code{pair} to avoid conflicts with R's \code{\link[base]{pairs}} function!!}
\seealso{\code{\link{point}}}
\examples{
\testonly{
# prepare variables from other example pages if they are not already there:
if(length(ls(pat="maas.point"))==0){example(point)}
}
maas.pair   <- pair(maas.point,num.lags=10,maxdist=2000)
maas.pair25 <- pair(maas.point,num.lags=10,type='anisotropic',
                      theta=25,maxdist=500)
}
\references{
http://www.gis.iastate.edu/SGeoStat/homepage.html
}
\keyword{spatial}

\eof
\name{plot.point}
\title{Plot Point Objects}
\usage{plot.point(x, v, legend.pos=0,axes=TRUE,xlab='',ylab='', add=FALSE, ...) }
\alias{plot.point}
\arguments{
  \item{x}{a point object generated by \code{point()}}
  
  \item{v}{an optional variable name, if entered will divide the points into quantiles and color using 4 colors}
  \item{legend.pos}{position of legend (0 - none, 1 - bottom-left, 2
    -bottom-right, 3 - top-right, 4 - top-left), requires Lang(v)}
  \item{axes}{logical, whether to plot axes}
  \item{xlab,ylab}{axes labels, default none}
  \item{add}{usefull for overlaying \code{image}s with a \code{point}
    plot}
  \item{...}{additional arguments for \code{plot}}
}
\value{NULL}
\description{ Plot the spatial locations in a point object, optionally coloring by quantile.}
\seealso{\code{\link{point}}}
\examples{
\testonly{
if(length(ls(pat="maas.point"))==0){example(point)}
}
plot(maas.point) 
plot(maas.point,v='zinc') 
plot(maas.point,v='zinc',xlab='easting',ylab='northing',axes=TRUE,legend.pos=4)
# plot additionally the maas bank:
data(maas.bank)
lines(maas.bank)
}
\references{
http://www.gis.iastate.edu/SGeoStat/homepage.html
}
\keyword{spatial}

\eof
\name{plot.variogram}
\title{Plot Variogram}
\usage{plot.variogram(x, var.mod.obj, title.str,ylim, type='c',N=FALSE, ...) }
\alias{plot.variogram}
\arguments{
  \item{x}{a variogram object generated by \code{est.variogram()}}
  \item{var.mod.obj}{a variogram model object generated by a model
    fitting routine.}
  \item{title.str}{optional: an user supplied plot title}
  \item{type}{optional: which type of variogram model to plot,
    \code{'c'} = classical, \code{'r'} = robust, \code{'m'} median}
  \item{N}{logical, toggles printing of absolute pair counts per lag}
  \item{ylim}{optonal user supplied y dimension for the plot}
  \item{...}{additional arguments for \code{plot}}
}
\value{NULL }
\description{Plot empirical variogram estimates, optionally plotting a fitted variogram model. }
\seealso{\code{\link{est.variogram}}}
\examples{
\testonly{
# prepare variables from other example pages if they are not already there:
if(length(ls(pat="maas.vmod"))==0){example(fit.variogram)}
}
# two plots 
oldpar <- par(mfrow=c(2,1))
plot(maas.v) 
plot(maas.v,var.mod.obj=maas.vmod)
par(oldpar)
}
\references{
http://www.gis.iastate.edu/SGeoStat/homepage.html
}
\keyword{spatial}

\eof
\name{point}
\title{Point Object}
\usage{point(dframe, x='x', y='y') }
\alias{point}
\arguments{
\item{dframe}{a data frame containing the x and y coordinates for each point and the variables observed at each point}
\item{x}{the name of the column in \code{dframe} that contains the x coordinate}
\item{y}{the name of the column in \code{dframe} that contains the y coordinate}
}
\value{A point object:
\item{x}{vector of x coordinates}
\item{y}{vector of ycoordinates}
\item{var1}{vector of the first variable}
\item{...}{...}
\item{varm}{vector of the mth variable}
}
\description{Create an object of class point from a data frame.

An object of class point represents the observed data of a spatial process. This includes the spatial location of sampling sites and
the values observed at those sites. A point object is stored as a data frame. The data frame must contain one column for the X
coordinate and one column for the Y coordinate of each point, as well as any number of columns representing data observed at the
points. }
\seealso{\code{\link{point}}}
\examples{
data(maas)
maas.point <- point(maas) 
}
\references{
http://www.gis.iastate.edu/SGeoStat/homepage.html
}
\keyword{spatial}

\eof
\name{print.pair}
\title{Pairs Object Description}
\usage{print.pair(x,...) }
\alias{print.pair}
\arguments{
  \item{x}{a pair object generated by \code{pair()}}
  \item{...}{additional arguments for \code{print}}
}
\value{NULL}
\description{Print descriptive information about a pair object. }
\seealso{\code{\link{pair}}}
\examples{
\testonly{
# prepare variables from other example pages if they are not already there:
if(length(ls(pat="maas.pair"))==0){example(pair)}
}
print(maas.pair)
# gives:
# Pairs object: maas.pair 
#
#      Type:             isotropic
#      Number of pairs:  8370
#      Number of lags:   10
#      Max h:            1999.867
}
\references{
http://www.gis.iastate.edu/SGeoStat/homepage.html
}
\keyword{spatial}

\eof
\name{print.point}
\title{Point Object Description}
\usage{print.point(x,...) }
\alias{print.point}
\arguments{
  \item{x}{a point object generated by \code{point()}}
  \item{...}{additional arguments for \code{print}}
}
\value{NULL}
\description{Print descriptive information about a point object.}
\seealso{\code{\link{point}}}
\examples{
\testonly{
if(length(ls(pat="maas.point"))==0){example(point)}
}
print.point(maas.point)
# gives
# Point object: maas.point 
#
#   Locations: 155
#
#   Attributes:
#      x
#      y
#      zinc
}
\references{
http://www.gis.iastate.edu/SGeoStat/homepage.html
}
\keyword{spatial}

\eof
\name{sgeostat-internal}
\alias{calcangle}
\alias{export.point}
\alias{krige.all}
\alias{krige.maxdist}
\alias{pair.aniso}
\alias{pair.iso}
\alias{pair.newangle}
\alias{prediction.matrix}
\alias{trend.matrix}
\alias{trend.value}
\alias{which.na}
\title{Internal sgeostat functions}
\description{
 Internal sgeostat functions
}
\details{
  These functions are not intended to be called by the user.
 
  The \code{\link{krige}} function interfaces to \code{krige.*}, \code{\link{pair}}
  to \code{pair.*} and \code{\link{fit.trend}} to \code{trend.*}.
}
\keyword{spatial}

\eof
\name{spacebox}
\title{Boxplot of Variogram Cloud}
\usage{spacebox(point.obj, pair.obj, a1, a2, type='r')}
\alias{spacebox}
\arguments{
\item{point.obj}{a point object generated by \code{point()}}
\item{pair.obj}{a pairs object generated by \code{pair()}}
\item{a1}{a variable to plot}
\item{a2}{an optional variable name, if entered the plot will be created between \code{a1} and \code{a2}}
\item{type}{either \code{'r'} for square-root differences or \code{'s'} for squared differences}
}
\value{NULL}
\description{Create  boxplots of square-root or squared differences between variable values at pairs of points versus the distance
       between the points. }
\seealso{\code{\link{point}}, \code{\link{pair}}}
\examples{
\testonly{
# prepare variables from other example pages if they are not already there:
if(length(ls(pat="maas.pair"))==0){example(pair)}
}
spacebox(maas.point,maas.pair,'zinc')
}
\references{
http://www.gis.iastate.edu/SGeoStat/homepage.html
}
\keyword{spatial}

\eof
\name{spacecloud}
\title{Variogram Cloud}
\usage{spacecloud(point.obj, pair.obj, a1, a2, type='r', query.a, ...)}
\alias{spacecloud}
\arguments{
\item{point.obj}{a point object generated by \code{point()}}
\item{pair.obj}{a pair object generated by \code{pair()}}
\item{a1}{a variable to plot}
\item{a2}{an optional variable name, if entered the plot will be created between \code{a1} and \code{a2}}
\item{type}{either \code{'r'} for square-root differences or \code{'s'} for squared differences}
\item{query.a}{an optional variable name, if entered, the value of the variable will be displayed on the graphics device for points
identified by the user.}
\item{...}{additional arguments for \code{plot}}
}
\value{NULL}
\description{Create a scatter plot of square-root or squared differences between variable values at pairs of points versus the distance
between the points. }
\note{When \code{query.a} is entered, the user will be prompted to identify points on the display device. Because each point in the
plot represents a pair of locations, the user must identify each point twice, once for the "from" point and once for the "to"
point. Querying is ended by pressing the middle mouse button on the mouse while the cursor is in the display window. }
\seealso{\code{\link{point}}, \code{\link{pair}}}
\examples{
\testonly{
# prepare variables from other example pages if they are not already there:
if(length(ls(pat="maas.pair"))==0){example(pair)}
}
opar <- par(ask = interactive() && .Device == "X11")
spacecloud(maas.point,maas.pair,'zinc')
# identify some points:
spacecloud(maas.point,maas.pair,'zinc',query.a='zinc')
par(opar)
}
\references{
http://www.gis.iastate.edu/SGeoStat/homepage.html
}
\keyword{spatial}

\eof
